@@ -1,3 +1,3 @@
-from .kci import KCI_UInd, KCI_CInd
 from .hsic import hsic_test_gamma
-from .kmi import kernel_mutual_information
\ No newline at end of file
+from .kci import KCI_CInd, KCI_UInd
+from .kmi import kernel_mutual_information
